Function alloc_data::prelude::err::unwrap_register_fatal
source · [−]Expand description
Destroys a unit result, registering the error as fatal if any.
Destroys a unit result, registering the error as fatal if any.